@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use feature qw(state);
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 use Carp qw(carp croak);
 use ExtUtils::Installed;
@@ -16,7 +16,7 @@ use Directory::Iterator;
 our $Upgrade    = 0;
 our $myLib      = 'lib';
 our $toCpanfile = 0;
-my $RE      = qr/\w+\.((?i:p[ml]|t|cgi|psgi))$/;
+my $qr4ext  = qr/\w+\.(p[ml]|t|cgi|psgi)$/;
 my $qr4name = qr/[a-zA-Z][a-zA-Z\d]+(?:::[a-zA-Z\d]+){0,}/;
 
 sub scanDir {    # To Do
@@ -37,8 +37,8 @@ sub scan {
     my %args = @_;
     my %pairs;
     while ( my $file = shift @{ $args{files} } ) {
-        $file =~ $RE;
-        my $ext = $1 || croak 'Unvalid extension was set';
+        ( my $ext = $file ) =~ $qr4ext;
+        warn "Invalid extension was set: $ext" unless $1;
         open my $fh, '<', $file or die "Can't open < $file: $!";
         while (<$fh>) {
             chomp;
@@ -71,27 +71,36 @@ sub scan {
             } elsif ( $eval and /\b(require|use)\s+($qr4name)/ ) {
                 warnIgnored( $2, $1, 'eval' );
             }
+            next if $eval;
+
+            if (/\buse\b/) {
+                scan_line( \%pairs, $_ );
+                next;
+            }
+
             state $if = 0;
             if (/^\b(?:if|unless)\s*\(.*\)\s*{$/) {
                 $if++;
             } elsif ( $if > 0 and /^\s*}$/ ) {
                 $if--;
+                warn "something wrong to parse: $file" if $if < 0;
                 next;
-            } elsif ( $if > 0 and /^\b(require|use)\s+($qr4name)/ ) {
-                warnIgnored( $2, $1, 'if' );
+            } elsif ( $if > 0 and /^\brequire\s+($qr4name)/ ) {
+                warnIgnored( 'require', $1, 'if' );
             }
-            next if $eval or $if;
+            next unless /\b(require|use)\s+/;
             scan_line( \%pairs, $_ );
         }
         close $fh;
     }
     my $deps  = {};
     my @local = ();
-    my $list  = Directory::Iterator->new($myLib);
+    my $list  = Directory::Iterator->new($myLib)
+        ;    # To Do: $myLib must be got from local::lib within plenv/PerlBrew
     while ( $list->next ) {
         my $file = $list->get;
-        next unless $file =~ s/\.p[lm]$//;
-        $file =~ s|/|::|g;
+        next unless $file =~ s!\.pm$!!;
+        $file =~ s!/!::!g;
         push @local, $file;
     }
 
@@ -120,7 +129,9 @@ sub scan_line {
     my $pairs = shift;
     local $_ = shift;
     my @names = ();
-    return if /^\b(?:require|use)\s+5\.\d{3}_?\d{3};$/;
+    return if /^\buse\s+v5(?:\.\d{2}){1,2}\s*;/;    #ignore VERSION
+    return if /^\buse\s+5\.\d{3}(?:_\d{3})?;/;      #ignore old version
+
     if (/use\s+(?:base|parent)\s+qw[\("']\s*((?:$qr4name\s*){1,})[\)"']/) {
         push @names, split /\s+/, $1;
     } elsif (/use\s+(?:base|parent|autouse)\s+(['"])?($qr4name)\1?/) {
@@ -145,7 +156,7 @@ sub scan_line {
         next if exists $pairs->{$name};
         next if $name eq 'Plack::Builder';
         next if first { $name eq $_ } @pragmas;
-        next if $Upgrade and Module::CoreList->is_core($name);
+        next if !$Upgrade and Module::CoreList->is_core($name);
         $pairs->{$name} = get_version($name);
     }
     return %$pairs;
@@ -156,9 +167,9 @@ sub get_version {
     my $installed = ExtUtils::Installed->new( skip_cwd => 1 );
     my $module    = first { $_ eq $name } $installed->modules();
     my $version   = eval { $installed->version($module) };
-    return "$version" if $version;
+    return $version if defined $version;
     eval "use lib '$myLib'; require $name" or return undef;
-    return eval "no strict 'subs';\$${name}::VERSION" || 0;
+    return eval "no strict 'subs';\$${name}::VERSION";
 }
 
 sub warnIgnored {
@@ -172,7 +183,7 @@ sub _name {
     my $str = shift;
     $str =~ s!/!::!g if $str =~ /\.pm$/;
     $str =~ s!^lib::!!;
-    $str =~ s!.pm$!!i;
+    $str =~ s!\.pm$!!;
     $str =~ s!^auto::(.+)::.*!$1!;
     return $str;
 }
