@@ -5,24 +5,23 @@ use lib 't/lib';
 
 my @dummys = ( 1, 1, 0, 0, 1 );
 
-# the all inside of 'if' nested sholud NOT to be parsed
+# the all `require` inside of `if` sholud NOT to be parsed
 
 unless ( shift @dummys ) {
-    require Require::With::If;    # braced
+    require Module::Exists::Unexpected;    # braced
 }
 
 unless ( shift @dummys ) {    # comment
-    require Require::With::If::Commented;    # double braced
+    require Module::Exists::Unexpected;    # double braced
 }    # comment
 
 unless ( shift @dummys ) {    # first
     unless ( shift @dummys ) {    # second
         unless ( shift @dummys ) {    # third
-            require Require::With::Nested::If;    # triple braced
+            require Module::Exists::Unexpected;    # triple braced
         }
     }
 }
 
-require Dummy;                                    # does not exist anywhere
+require Acme::BadExample;    # does not exist anywhere
 
-exit;
