@@ -8,7 +8,7 @@ my @dummys = ( 1, 0, 0, 0, 1, 1 );
 if ( shift @dummys ) {    # first
     unless ( shift @dummys ) {    # second
         if ( shift @dummys ) {    # third
-            require Require::With::Nested::If;    # triple braced
+            require Module::Exists::Unexpected;    # triple braced
         }
     }
 }
@@ -16,11 +16,10 @@ if ( shift @dummys ) {    # first
 unless ( shift @dummys ) {    # first
     if ( shift @dummys ) {    # second
         unless ( shift @dummys ) {    # third
-            require Require::With::Nested::If;    # triple braced
+            require Module::Exists::Unexpected;    # triple braced
         }
     }
 }
 
-require Dummy;                                    # does not exist anywhere
+require Acme::BadExample;    # does not exist anywhere
 
-exit;
